[pypy-svn] r35551 - pypy/dist/pypy/objspace/test

arigo at codespeak.net arigo at codespeak.net
Sun Dec 10 15:27:19 CET 2006


Author: arigo
Date: Sun Dec 10 15:27:16 2006
New Revision: 35551

Modified:
   pypy/dist/pypy/objspace/test/test_logicobjspace.py
Log:
We added an extra recursion level in the interpreter main loop, which
makes this test exhaust the CPython stack a bit earlier than before.



Modified: pypy/dist/pypy/objspace/test/test_logicobjspace.py
==============================================================================
--- pypy/dist/pypy/objspace/test/test_logicobjspace.py	(original)
+++ pypy/dist/pypy/objspace/test/test_logicobjspace.py	Sun Dec 10 15:27:16 2006
@@ -476,9 +476,9 @@
                 
         X = newvar()
         F = future(fib, X)
-        # values > 11 triggers exhaustion of the cpython stack
-        unify(11, X)
-        assert F == 144
+        # values > 10 triggers exhaustion of the cpython stack
+        unify(10, X)
+        assert F == 89
 
     def test_stacklet(self):
 



More information about the Pypy-commit mailing list